/*
 * This macro allows you to use a 'C' function to handle a 68HC12 interrupt.
 *
 * The only parameter is the DECIMAL address of the interrupt vector.
 * NOTE: If you are debugging with a monitor or other software which re-
 * vectors the interrupts through a RAM vector table, be sure to use the
 * address of the RAM vector, NOT the actual CPU vector which will likely
 * be in ROM.
 *
 * The macro MUST be placed IMMEDIATELY preceeding the definition of the
 * function which is to be the interrupt handler. Example:
 *
 * 		INTERRUPT(_SER_) serial_int_handler()
 * 		{
 *			/* ... Function code to handle serial interrupt ... */
 *		}
 *
 * *Note1:	If the '?temp' location is in the zero page of memory, you
 *			can use <direct addressing and subtract 2 from the BSR offset.
 *
 * *Note2:	Some monitors may re-vector the interrupts using JMP instructions
 *			in the RAM vector table instead of vectors (like MON12 and the
 *			68HC12 CPU itself do). If you are using such a debugger, you need
 *			to change the FDB near the beginning of the macro to JMP.
 *			Motorola's D-Bug12 (supplied with the EVB) does not document the
 *			address of the RAM re-vector table, however it can be obtained
 *			via a function call (ref: "Using and Extending D-Bug12 Routines").
 *
 * This file **REQUIRES** the extended pre-processor (MCP).
 * (CC12 ... -P, or "Preprocess" step enabled in DDSIDE)
 *
 * Copyright 1991-2005 Dave Dunfield
 * All rights reserved.
 */
#define	_SP_				/* Null separator */
#define	INTERRUPT(vec) asm {\
$SE:0						/* Insure output in code segment */\
_/**/vec	/* This label will be the address of the "prefix" stub */\
		ORG		vec			/* Position to interrupt vector */\
		FDB		_/**/vec	/* Enter the label address */\
		ORG		_/**/vec	/* Position back to original PC */\
		LDX		_SP_>?temp	/* Get temporary location */\
		PSHX				/* Save during interrupt */\
		BSR		_/**/vec+11	/* Invoke 'C' interrupt handler*/\
		PULX				/* Restore temporary location value*/\
		STX		_SP_>?temp	/* Replace value */\
		RTI					/* End interrupt */\
}
#undef _SP_
